pub struct HashTable<T: HTEntry> { /* private fields */ }Implementations
Sourceimpl<T: HTFromKey> HashTable<T>
impl<T: HTFromKey> HashTable<T>
Sourceimpl<T: HTEntry> HashTable<T>
impl<T: HTEntry> HashTable<T>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn has<K>(&self, key: &K) -> bool
Sourcepub fn find<K>(&self, key: &K) -> Option<&T>
pub fn find<K>(&self, key: &K) -> Option<&T>
Finds a reference to the value corresponding to the key
or returns None if the key is not present in the table.
Sourcepub fn find_mut<K>(&mut self, key: &K) -> Option<&mut T>
pub fn find_mut<K>(&mut self, key: &K) -> Option<&mut T>
Finds a mutable reference to the value corresponding to the key
or returns None if the key is not present in the table.
pub fn insert(&mut self, item: T)
pub fn extract_if<'a, F>(&'a mut self, f: F) -> impl Iterator<Item = T> + 'a
pub fn remove<K>(&mut self, key: &K) -> Option<T>
pub fn find_entry<K>( &mut self, key: &K, ) -> Result<OccupiedEntry<'_, T>, AbsentEntry<'_, T>>
pub fn entry<K>(&mut self, key: &K) -> Entry<'_, T>
pub fn iter(&self) -> Iter<'_, T>
pub fn iter_mut(&mut self) -> IterMut<'_, T>
pub fn first_key(&self) -> Option<T::Key>